@@ -5,25 +5,17 @@ use Result;
 /// A type that can read.
 pub trait Tape: Read + Seek + Sized {
     /// Read a value.
-    #[inline(always)]
+    #[inline]
     fn take<T: Value>(&mut self) -> Result<T> {
         Value::read(self)
     }
 
     /// Read a value given a parameter.
-    #[inline(always)]
+    #[inline]
     fn take_given<T: Walue<P>, P>(&mut self, parameter: P) -> Result<T> {
         Walue::read(self, parameter)
     }
 
-    #[doc(hidden)]
-    fn count(&mut self) -> Result<u64> {
-        let current = try!(self.position());
-        let end = self.seek(SeekFrom::End(0));
-        try!(self.jump(current));
-        end
-    }
-
     #[doc(hidden)]
     #[inline]
     fn jump(&mut self, position: u64) -> Result<u64> {
@@ -62,7 +54,7 @@ impl<T: Read + Seek> Tape for T {}
 macro_rules! read(
     ($tape:ident, $size:expr) => (unsafe {
         let mut buffer: [u8; $size] = ::std::mem::uninitialized();
-        try!(::std::io::Read::read($tape, &mut buffer));
+        try!(::std::io::Read::read_exact($tape, &mut buffer));
         ::std::mem::transmute(buffer)
     });
 );
